%define major 9
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Summary:	Tokyo Cabinet: a modern implementation of DBM
Name:		tokyocabinet
Version:	1.4.47
Release:	9
License:	LGPLv2.1+
Group:		System/Libraries
Url:		http://1978th.net/tokyocabinet/
Source0:	http://1978th.net/%{name}/%{name}-%{version}.tar.gz
Patch0:		tokyocabinet-mdv_conf.diff
Patch1:		tokyocabinet-1.4.9-lzmalib_linkage_fix.diff
BuildRequires:	bzip2-devel
BuildRequires:	liblzo-devel
BuildRequires:	lzmalib-devel
BuildRequires:	pkgconfig(zlib)

%description
Tokyo Cabinet is a library of routines for managing a database. The database is
a simple data file containing records, each is a pair of a key and a value.
Every key and value is serial bytes with variable length. Both binary data and
character string can be used as a key and a value. There is neither concept of
data tables nor data types. Records are organized in hash table or B+ tree.

As for database of hash table, each key must be unique within a database, so it
is impossible to store two or more records with a key overlaps. The following
access methods are provided to the database: storing a record with a key and a
value, deleting a record by a key, retrieving a record by a key. Moreover,
traversal access to every key are provided, although the order is arbitrary.
These access methods are similar to ones of DBM (or its followers: NDBM and
GDBM) library defined in the UNIX standard. Tokyo Cabinet is an alternative for
DBM because of its higher performance.

As for database of B+ tree, records whose keys are duplicated can be stored.
Access methods of storing, deleting, and retrieving are provided as with the
database of hash table. Records are stored in order by a comparison function
assigned by a user. It is possible to access each record with the cursor in
ascending or descending order. According to this mechanism, forward matching
search for strings and range search for integers are realized. Moreover,
transaction is available in database of B+ tree.

Tokyo Cabinet is written in the C language, and provided as API of C, Perl,
Ruby, and Java. Tokyo Cabinet is available on platforms which have API
conforming to C99 and POSIX. Tokyo Cabinet is a free software licensed under
the GNU Lesser General Public License.

%files
%{_bindir}/*
%{_mandir}/man1/*

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Tokyo Cabinet: a modern implementation of DBM
Group:		System/Libraries

%description -n %{libname}
Tokyo Cabinet is a library of routines for managing a database. The database is
a simple data file containing records, each is a pair of a key and a value.
Every key and value is serial bytes with variable length. Both binary data and
character string can be used as a key and a value. There is neither concept of
data tables nor data types. Records are organized in hash table or B+ tree.

%files -n %{libname}
%doc COPYING ChangeLog README doc/* lab/magic
%{_libdir}/libtokyocabinet.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Static library and header files for the tokyocabinet library
Group:		Development/C
Requires:	%{libname} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}

%description -n %{devname}
Tokyo Cabinet is a library of routines for managing a database. The database is
a simple data file containing records, each is a pair of a key and a value.
Every key and value is serial bytes with variable length. Both binary data and
character string can be used as a key and a value. There is neither concept of
data tables nor data types. Records are organized in hash table or B+ tree.

This package contains the static library and its header files.

%files -n %{devname}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/tokyocabinet.pc
%{_mandir}/man3/*

#----------------------------------------------------------------------------

%package tcawmgr
Summary:	The CGI utility of the abstract database API (tokyocabinet)
Group:		System/Servers
Requires:	%{libname} = %{EVRD}
Requires:	apache

%description tcawmgr
The CGI utility of the abstract database API (tokyocabinet).

%files tcawmgr
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/httpd/conf/webapps.d/tcawmgr.conf
%attr(0755,root,root) /var/www/cgi-bin/tcawmgr.cgi

#----------------------------------------------------------------------------

%prep
%setup -q
%patch0 -p1
%patch1 -p0

%build
rm -f configure
autoconf

%configure2_5x \
	--disable-static \
	--enable-zlib \
	--enable-bzip \
	--enable-pthread \
	--enable-exlzma \
	--enable-exlzo

%make \
	CFLAGS="-std=c99 -Wall -fPIC -fsigned-char %{optflags}" \
	LDFLAGS="%{ldflags} -L. -L%{_libdir}"

%install
%makeinstall_std

install -d %{buildroot}/var/www/cgi-bin
mv %{buildroot}%{_libdir}/tcawmgr.cgi %{buildroot}/var/www/cgi-bin/

install -d %{buildroot}%{_sysconfdir}/httpd/conf/webapps.d
cat > %{buildroot}%{_sysconfdir}/httpd/conf/webapps.d/tcawmgr.conf << EOF
<Location /cgi-bin/tcawmgr.cgi>
    Require local granted
    ErrorDocument 403 "Access denied per %{_sysconfdir}/httpd/conf/webapps.d/tcawmgr.conf"
</Location>
EOF

# cleanup
rm -rf %{buildroot}%{_datadir}/%{name}
rm -f doc/*~

%check
%make check


%changelog

* Mon May 09 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.4.47-9
- (8120075) Build with system optflags
- (8120075) Spec cleanup


